==> nextcloud-29.0.12.tgz: nextcloud/apps/password_policy/l10n/sv.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Lösenordet har gått ut, vänligen använd 'Glömt lösenordet?' för att återställa",
    "Password must not have been used recently before." : "Lösenordet får inte ha använts nyligen.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Lösenord är bland de 1 000 000 vanligaste. Vänligen ändra till ett unikt.",
    "Password is present in compromised password list. Please choose a different password." : "Lösenordet finns i listan över läckta lösenord. Vänligen välj ett annat lösenord.",
    "Password needs to be at least %s characters long." : "Lösenordet måste vara minst %s tecken långt.",
    "Password needs to contain at least one numeric character." : "Lösenordet måste innehålla minst en siffra..",
    "Password needs to contain at least one special character." : "Lösenordet måste innehålla minst ett specialtecken.",
    "Password needs to contain at least one lower and one upper case character." : "Lösenordet måste innehålla minst en liten och en stor bokstav.",
    "Password policy" : "Lösenordsregler",
    "Allows admins to configure a password policy" : "Låter administratörer konfigurera regler för lösenord",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Låter administratören att definiera vissa villkor för lösenord, t.ex. en minimilängd",
    "General password policies" : "Allmänna lösenordspolicyer",
    "Add policy set" : "Lägg till policyuppsättning",
    "Login policies" : "Inloggningspolicyer",
    "Password history size" : "Lösenordshistorikens storlek",
    "Number of passwords to keep (securely hashed) to prevent users from reusing previously used passwords." : "Antal lösenord att spara (säkert hashade) för att förhindra användare från att återanvända tidigare använda lösenord.",
    "Maximum login attempts" : "Maximalt antal inloggningsförsök",
    "Number of login attempts before the user account will be disabled until manual action is taken. (0 for no limit)" : "Antal inloggningsförsök innan användarens konto inaktiveras tills manuell åtgärd vidtas. (0 för ingen begränsning)",
    "Please note, this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "Observera att detta alternativet är avsett att skydda attackerade konton. Inaktiverade konton måste återaktiveras manuellt av administratören. Angripare som försöker gissa lösenord för konton kommer att få sin IP-adress blockerad av bruteforce-skyddet oberoende av denna inställning.",
    "Number of days until user password expires" : "Antal dagar tills användarens lösenord går ut",
    "Password expiration" : "Lösenordsutgång",
    "Warning: enabling password expiration is nowadays considered a security risk by several security agencies." : "Varning: att aktivera utgångstider för lösenord anses numera vara en säkerhetsrisk av flera säkerhetsorgan.",
    "Remove policy" : "Ta bort policy",
    "Minimum password length" : "Minsta lösenordslängd",
    "Forbid common passwords" : "Förbjud de vanligaste lösenorden",
    "Enforce upper and lower case characters" : "Kräv stor och liten bokstav i lösenordet",
    "Enforce numeric characters" : "Kräv en siffra i lösenordet",
    "Enforce special characters" : "Kräv specialtecken i lösenordet",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Kontrollera lösenordet mot listan med läckta lösenord från haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Denna kontroll skapar en hash av lösenordet och skickar de 5 första tecknen i denna hash till haveibeenpwned.com för att hämta en lista över alla hashar som börjar med dessa. Sedan kontrollerar den på Nextcloud-instansen om lösenordshashen finns med i listan.",
    "Account password policies" : "Lösenordspolicyer för konto",
    "Share password policies" : "Lösenordspolicyer för delning",
    "User password history" : "Lösenordshistorik",
    "Please note, that this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "Observera att detta alternativet är avsett att skydda attackerade konton. Inaktiverade konton måste återaktiveras manuellt av administratören. Angripare som försöker gissa lösenord för konton kommer att få sin IP-adress blockerad av bruteforce-skyddet oberoende av denna inställning.",
    "Unknown error" : "Okänt fel",
    "Minimal length has to be a non negative number" : "Minimilängden måste vara ett icke-negativt tal",
    "History size has to be a non negative number" : "Historikens storlek måste vara ett icke-negativt tal",
    "Expiration days have to be a non negative number" : "Dagar till utgång måste vara ett icke-negativt tal",
    "Maximum login attempts have to be a non negative number" : "Maximalt antal inloggningsförsök måste vara ett icke-negativt tal",
    "Settings saved" : "Inställningar sparade",
    "Error while saving settings" : "Fel vid sparande av inställningar"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.5.tgz: nextcloud/apps/password_policy/l10n/sv.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Lösenordet har gått ut, vänligen använd 'Glömt lösenordet?' för att återställa",
    "Password must not have been used recently before." : "Lösenordet får inte ha använts nyligen.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Lösenord är bland de 1 000 000 vanligaste. Vänligen ändra till ett unikt.",
    "Password is present in compromised password list. Please choose a different password." : "Lösenordet finns i listan över läckta lösenord. Vänligen välj ett annat lösenord.",
    "Password needs to be at least %s characters long." : "Lösenordet måste vara minst %s tecken långt.",
    "Password needs to contain at least one numeric character." : "Lösenordet måste innehålla minst en siffra..",
    "Password needs to contain at least one special character." : "Lösenordet måste innehålla minst ett specialtecken.",
    "Password needs to contain at least one lower and one upper case character." : "Lösenordet måste innehålla minst en liten och en stor bokstav.",
    "Password policy" : "Lösenordsregler",
    "Allows admins to configure a password policy" : "Låter administratörer konfigurera regler för lösenord",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Låter administratören att definiera vissa villkor för lösenord, t.ex. en minimilängd",
    "Minimum password length" : "Minsta lösenordslängd",
    "User password history" : "Lösenordshistorik",
    "Number of login attempts before the user account will be disabled until manual action is taken. (0 for no limit)" : "Antal inloggningsförsök innan användarens konto inaktiveras tills manuell åtgärd vidtas. (0 för ingen begränsning)",
    "Please note, this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "Observera att detta alternativet är avsett att skydda attackerade konton. Inaktiverade konton måste återaktiveras manuellt av administratören. Angripare som försöker gissa lösenord för konton kommer att få sin IP-adress blockerad av bruteforce-skyddet oberoende av denna inställning.",
    "Number of days until user password expires" : "Antal dagar tills användarens lösenord går ut",
    "Warning: enabling password expiration is nowadays considered a security risk by several security agencies." : "Varning: att aktivera utgångstider för lösenord anses numera vara en säkerhetsrisk av flera säkerhetsorgan.",
    "Forbid common passwords" : "Förbjud de vanligaste lösenorden",
    "Enforce upper and lower case characters" : "Kräv stor och liten bokstav i lösenordet",
    "Enforce numeric characters" : "Kräv en siffra i lösenordet",
    "Enforce special characters" : "Kräv specialtecken i lösenordet",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Kontrollera lösenordet mot listan med läckta lösenord från haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Denna kontroll skapar en hash av lösenordet och skickar de 5 första tecknen i denna hash till haveibeenpwned.com för att hämta en lista över alla hashar som börjar med dessa. Sedan kontrollerar den på Nextcloud-instansen om lösenordshashen finns med i listan.",
    "Unknown error" : "Okänt fel",
    "Minimal length has to be a non negative number" : "Minimilängden måste vara ett icke-negativt tal",
    "History size has to be a non negative number" : "Historikens storlek måste vara ett icke-negativt tal",
    "Expiration days have to be a non negative number" : "Dagar till utgång måste vara ett icke-negativt tal",
    "Maximum login attempts have to be a non negative number" : "Maximalt antal inloggningsförsök måste vara ett icke-negativt tal",
    "Settings saved" : "Inställningar sparade",
    "Error while saving settings" : "Fel vid sparande av inställningar",
    "Please note, that this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "Observera att detta alternativet är avsett att skydda attackerade konton. Inaktiverade konton måste återaktiveras manuellt av administratören. Angripare som försöker gissa lösenord för konton kommer att få sin IP-adress blockerad av bruteforce-skyddet oberoende av denna inställning."
},
"nplurals=2; plural=(n != 1);");
